import org.w3c.dom.*;

/**
 * A class that contains two DOM elements (named with rdf:subject or rdf:object)
 * and identify if we return one or the other with a boolean 
 * @author Sébastien Laborie and Antoine Zimmermann
 */
public class SubjectOrObject {
    
    private Document document;
    
    private Element subject;
    
    private Element object;
    
    private Element literalvalue;
    
    public SubjectOrObject(Document document){
        this.document = document;
        subject = document.createElement("rdf:subject");
        object = document.createElement("rdf:object");
        literalvalue = document.createElement("sparql:literalvalue");
    }
    
    public SubjectOrObject(Document document, Element subject, Element object, Element literalvalue){
        this.document = document;
        this.subject = subject;
        this.object = object;
        this.literalvalue = literalvalue;
    }
    
    public void setAttribute(String name, String value){
        subject.setAttribute(name, value);
        object.setAttribute(name, value);
        literalvalue.setAttribute(name, value);
    } 
    
    public Element getSubject(){
        return this.subject;
    }
    
    public Element getObject(){
        return this.object;
    }
    
    public Element getLiteralValue(){
        return this.literalvalue;
    }
    
    public void appendChild(Node newChild){
        subject.appendChild(newChild);
        object.appendChild(newChild);
        literalvalue.appendChild(newChild);
    }
    
    public SubjectOrObject cloneNode() {
        return new SubjectOrObject(document, (Element) subject.cloneNode(true), (Element) object.cloneNode(true), (Element) literalvalue.cloneNode(true));
    }

}
